api.system.components.configuration.v1.test_helpers.template package — Argus-Toolbelt 1.0 documentation

# api.system.components.configuration.v1.test_helpers.template package

## Submodules

## api.system.components.configuration.v1.test_helpers.template.add_comment module

`api.system.components.configuration.v1.test_helpers.template.add_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/comment, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.add_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/comment, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.add_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/comment, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.add_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/comment, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.create module

`api.system.components.configuration.v1.test_helpers.template.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.delete module

`api.system.components.configuration.v1.test_helpers.template.delete.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.delete.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.delete.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.delete.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.duplicate module

`api.system.components.configuration.v1.test_helpers.template.duplicate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/duplicate, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.duplicate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/duplicate, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.duplicate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/duplicate, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.duplicate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/duplicate, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.list module

`api.system.components.configuration.v1.test_helpers.template.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.revisions module

`api.system.components.configuration.v1.test_helpers.template.revisions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/revisions, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.revisions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/revisions, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.revisions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/revisions, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.revisions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+/revisions, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.search module

`api.system.components.configuration.v1.test_helpers.template.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/search, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/search, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/search, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/search, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.update module

`api.system.components.configuration.v1.test_helpers.template.update.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.update.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.update.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.update.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.template.view module

`api.system.components.configuration.v1.test_helpers.template.view.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.template.view.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.template.view.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.template.view.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/template/w+, respond with HTTP 401

## Module contents